@@ -1,10 +1,12 @@
 package HTML::Parser;
 
+# Author address: <gisle@aas.no>
+
 use strict;
 use HTML::Entities ();
 
 use vars qw($VERSION);
-$VERSION = "2.19";  # $Date: 1998/07/06 23:06:02 $
+$VERSION = "2.21";  # $Date: 1998/11/13 21:38:23 $
 
 
 sub new
@@ -75,8 +77,8 @@ sub parse
 	    }
 
 	# Netscapes buggy comments are easy to handle
-	} elsif ($netscape_comment && $$buf =~ m|^<!--|) {
-	    if ($$buf =~ s|^<!--(.*?)-->||s) {
+	} elsif ($netscape_comment && $$buf =~ m|^<!\s*--|) {
+	    if ($$buf =~ s|^<!\s*--(.*?)--\s*>||s) {
 		$self->comment($1);
 	    } else {
 		last TOKEN;  # must wait until we see the end of it
@@ -422,8 +424,8 @@ times slower with a chunck size of 20K).
 
 =head1 SEE ALSO
 
-L<HTML::Entities>, L<HTML::Filter>, L<HTML::HeadParser>,
-L<HTML::LinkExtor>
+L<HTML::Entities>, L<HTML::TokeParser>, L<HTML::Filter>,
+L<HTML::HeadParser>, L<HTML::LinkExtor>
 
 L<HTML::TreeBuilder> (part of the I<HTML-Tree> distribution)
 
